<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:xdt="http://www.w3.org/2005/xpath-datatypes">
<xsl:output encoding="UTF-8" method="text"/>
<xsl:param name="destinationPath"/>
<xsl:template match="/configuration-backup">
#   *******************************************************************
#   * Licensed Materials - Property of IBM
#   * Tivoli Common Agent Manager
#   * CTGEM
#   * (C) Copyright IBM Corp. 2003, 2004. All Rights Reserved
#   *
#   * US Government Users Restricted Rights - Use, duplication or
#   * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#   *******************************************************************
#   * Change Activity on Version 1.17 Dated 11/3/04:
#   * @00=AM,V1R1,09/30/2004,bst: Common file prolog added
#   *******************************************************************

################################################################################
#
# InstallShield Options File
#
#
# This file is used as the options file (i.e., response file) for the install
# wizard "Setup". Options files are used with "-options" on the command line to
# modify wizard options.
#
# The options that can be specified for the wizard are listed below. To use
# this template, follow these steps:
#
#    1. Enable an option below by removing leading '###' characters from the
#       line (search for '###' to find options you can change).
#
#    2. Specify a value for an option by replacing the value to the right of the
#       equal sign (=). Read each option's documentation for information about valid
#       values.
#
#       If the value contains a space character, enclose the value
#       in double quotation marks ("value"). Double quotes are allowed for all
#       options. For example: -P installLocation="C:\Program Files\My Product"
#
#       If you include the option in the response file, you must provide a value.
#       For the CertSettings.CaPassword option, the value may be the null string
#       (""). For all other options, you must provide a valid, non-null value.
#
#       WARNING: Input values to ISMP are case sensitive.  Where a comment indicates
#                a set of allowable values, the values MUST be entered in the case
#                indicated!
#
#    3. Save the changes to the file.
#
#    4. To use the options file with the wizard, specify -options &lt;file-name&gt;
#       as a command line argument to the wizard, where &lt;file-name&gt; is the name
#       of this options file.
#
#        Examples:
#            To load the GUI based install with response file options:
#               Using Java:
#                  java -cp setup.jar run -options &lt;responsefileName&gt;
#                or:
#                  java -jar setup.jar -options &lt;responsefileName&gt;
#
#               Using the executable launcher:
#                  Windows: setupwin32.exe   -options &lt;responsefileName&gt;
#                  Linux:   setupLinux.bin   -options &lt;responsefileName&gt;
#                  AIX:     setupAix.bin     -options &lt;responsefileName&gt;
#                  Solaris: setupSolaris.bin -options &lt;responsefileName&gt;
#
#            To run the silent install with these response file options:
#               Using Java:
#                  java -jar setup.jar -options &lt;responsefileName&gt; -silent
#                or:
#                  java -cp setup.jar run -options &lt;responsefileName&gt; -silent
#
#               Using the executable launcher:
#                  Windows: setupwin32.exe   -options &lt;responsefileName&gt; -silent
#                  Linux:   setupLinux.bin   -options &lt;responsefileName&gt; -silent
#                  AIX:     setupAix.bin     -options &lt;responsefileName&gt; -silent
#                  Solaris: setupSolaris.bin -options &lt;responsefileName&gt; -silent
#
################################################################################
#
# Input provided by exploiter can be specified in the following section.  If a
# value is left commented out, the listed default will be used.
#
################################################################################


############ Security Note #####################################################
# This file contains clear-text (unencrypted) passwords. Make sure that file and
# directory permissions prevent unauthorized persons from accessing this file,
# or delete the passwords from this file after the installation is complete.
#
# The following options contain passwords:
#    CASInstall.DBRuntimePassword
#    CASInstall.DBAdminPassword
#    CASInstall.CertificateAuthorityPassword
#    CASInstall.RegistrationPassword
#    CASInstall.AgentManagerPassword
#
# Note on passwords:
#   The following characters are not supported for use in CASInstall.RegistrationPassword,
#   CASInstall.CertificateAuthorityPassword, or CASInstall.AgentManagerPassword
#   (the characters are spelled out because some of these characters will cause
#   InstallShield on linux to abort if it encounters them, even in a comment):
#    - greater than
#    - less than
#    - double quote
#    - equals sign
#    - semi-colon
#    - comma
#    - caret
#    - forward slash
#    - ampersand
#    - vertical bar (pipe)
#    - British pound symbol
#    - space
################################################################################



################################################################################
# Install Type
#   Determines the installation type used by the AM installer, and
#   dictates the runtime behavior of the installer.
#
#   "install"   Installs Agent Manager.
#
#               If Agent Manager is already installed, you will get an error
#               message and the installation will stop. You must either modify
#               the response file to specify the "upgrade" option or uninstall
#               Agent Manager. In either case, you must restart the
#               installation.
#
#   "upgrade"   Upgrades Agent Manager from a previous release.  If the
#               installer detects that the Agent Manager is not already
#               installed, this value is automatically changed to "install".
#
#               When an existing Agent Manager is upgraded, the AM application
#               files will be updated, but no configuration changes (such as
#               WAS ports or passwords) are made.
#
#   "relocate"  Installs an Agent Manager 1.3 from another identically
#               configured Agent Manager.  This option uses a response file
#               created by the Agent Manager Migration Utility, and requires
#               access to that Agent Manager's certificate file and os.guid.
#
#   Note:
#     If you invoke the GUI installer with this value set to "install" on a
#     machine where Agent Manager is already installed, the installation stops.
#     The "InstallType" is unique among response keys in this regard; other
#     options can be modified during the course of the install.
#
#   Valid values:   "install", "upgrade", "relocate"
#   Default value:  "upgrade"
################################################################################
-W CASInstall.InstallType="relocate"

################################################################################
# ShowDestinationPanel
#   Dictates whether the Agent Manager installer prompts
#   the user for the install location.  If the value is "true", the user will
#   see the Destination Panel; if the value is "false", the panel is suppressed
#   and the value specified in the response file by "-P installLocation" will
#   dictate where the Agent Manager gets installed.
#
#   This value is set to false if one of the Middleware Installers (eg. Embedded
#   WebSphere Installer) has already prompted the user for the Agent Manager
#   install directory.
#
#   Valid values:   "true", "false"
#   Default value:  "true"
################################################################################
### -W CASInstall.ShowDestinationPanel="true"

################################################################################
# IgnorePortConflicts
#   Dictates whether the Agent Manager installer terminates when it detects
#   a port conflict, or logs a warning and continues on.  Setting this value
#   to "true" provides a way to force a silent install to terminate if conflicts
#   exist.
#
#   Valid values:   "true", "false"
#   Default value:  "true"
################################################################################
### -W CASInstall.IgnorePortConflicts="true"

################################################################################
# Agent Manager Install Location
#   The install location of Agent Manager. Specify a valid directory into which
#   AM should be installed. If the directory contains spaces, enclose it in
#   double-quotes. For example, to install the product to
#      C:\Program Files\My Product
#    use
#      -P installLocation="C:\Program Files\My Product"
#
#   Note:
#     WebSphere puts the Agent Manager WAR files into a WebSphere-managed
#     directory. All other Agent Manager files are put into the Agent Manager
#     Install Location.
#
#   Default Windows value: "C:\Program Files\IBM\AgentManager"
#   Default AIX value:     "/usr/IBM/AgentManager"
#   Default value on all other platforms: "/opt/IBM/AgentManager"
################################################################################
<xsl:choose>
	<xsl:when test="general/installationLocation">
# recovered:
-P installLocation="<xsl:value-of select="general/installationLocation"/>"
	</xsl:when>
	<xsl:otherwise>
### -P installLocation="C:\Program Files\IBM\AgentManager"
	</xsl:otherwise>
</xsl:choose>
################################################################################
# WebSphere Application Server install location
#
#   This value must be specified for an "install" scenario.  For an "upgrade"
#   scenario, the Agent Manager installer will determine the WAS location based
#   on its existing configuration.
#
#   Default Windows value: "C:\Program Files\WebSphere\AppServer"
#   Default AIX value:     "/usr/IBM/WebSphere/AppServer"
#   Default value on all other platforms: "/opt/IBM/WebSphere/AppServer"
################################################################################
<xsl:choose>
	<xsl:when test="container/WASLocation">
#recovered:
-W CASInstall.WASLocation="<xsl:value-of select="container/WASLocation"/>"
	</xsl:when>
	<xsl:otherwise>
### -W CASInstall.WASLocation="C:\Program Files\IBM\WebSphere\AppServer"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# WebSphere Profile location
#   The directory of the WebSphere Profile under which to install the Agent Manager.
#
#   Note:
#     CAS does not create WebSphere Profiles.  The profile location
#     specified must already exist on the local filesystem.
#
#   Default Windows value: "C:\Program Files\WebSphere\AppServer\profiles\default"
#   Default AIX value:     "/usr/IBM/WebSphere/AppServer/profiles/default"
#   Default value on all other platforms: "/opt/IBM/WebSphere/AppServer/profiles/default"
################################################################################
<xsl:choose>
	<xsl:when test="container/WASProfile">
#recovered:
-W CASInstall.WASProfileLocation="<xsl:value-of select="container/WASProfile"/>"
	</xsl:when>
	<xsl:otherwise>
### -W CASInstall.WASProfileLocation="C:\Program Files\IBM\WebSphere\AppServer\profiles\default"
	</xsl:otherwise>
</xsl:choose>
################################################################################
# WebSphere Cell Name
#   String indicating the WebSphere cell name under which the Agent Manager
#   applications will be installed.
#
#   If the default value of "CellName" is not changed, Agent Manager will log an
#   error during validation.
#
#   This value must be specified for an "install" scenario.  For an "upgrade"
#   scenario, the Agent Manager installer will determine the WAS Cell Name based
#   on its existing configuration.
#
#   Default value:  "CellName"
################################################################################
<xsl:choose>
	<xsl:when test="container/WASCell">
#recovered:
-W CASInstall.WASCellName="<xsl:value-of select="container/WASCell"/>"
	</xsl:when>
	<xsl:otherwise>
### -W CASInstall.WASCellName="localhostNode01Cell"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# WebSphere Node Name
#   String indicating the WebSphere node name under which the Agent Manager
#   applications will be installed.
#
#   If the default value of "NodeName" is not changed, Agent Manager will log an
#   error during validation.
#
#   This value must be specified for an "install" scenario.  For an "upgrade"
#   scenario, the Agent Manager installer will determine the WAS Node Name based
#   on its existing configuration.
#
#   Default value:  "NodeName"
################################################################################

<xsl:choose>
	<xsl:when test="container/WASNode">
#recovered:
-W CASInstall.WASNodeName="<xsl:value-of select="container/WASNode"/>"
	</xsl:when>
	<xsl:otherwise>
### -W CASInstall.WASNodeName="localhost"
	</xsl:otherwise>
</xsl:choose>


################################################################################
# Database Type
#   This is the type of database product that will be used by Agent Manager.
#
#   Valid values:  "db2"         DB/2 database
#                  "oracle"      Oracle database
#                  "cloudscape"  Cloudscape database
#
#   Default value: "db2"
################################################################################
<xsl:choose>
	<xsl:when test="db/DBType">
#recovered:
-W CASInstall.DBType="<xsl:value-of select="db/DBType"/>"
	</xsl:when>
	<xsl:otherwise>
### -W CASInstall.DBType="db2"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Database Connection Mode
#   Represents the location of the Agent Registry database.
#
#   Valid values:  "local"      database running on the same host
#                  "remote"     database running on a different host (DB/2 or Oracle only)
#                  "alias"      database running on a different host, but cataloged as a local alias (DB/2 only)
#
#   Default value: "local"
################################################################################
<xsl:choose>
	<xsl:when test="db/DBConnectionMode">
#recovered:
-W CASInstall.DBConnectionMode="<xsl:value-of select="db/DBConnectionMode"/>"
	</xsl:when>
	<xsl:otherwise>
### -W CASInstall.DBConnectionMode="local"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Database Name
#
#   DB2:        Symbolic name/alias of the registry database.
#   Oracle:     Name of the registry database.
#   Cloudscape: Directory where the registry database is located or where it will
#               be created. If you do not specify a fully qualified path name,
#               the database name is relative to the agent manager installation
#               directory.
#
#   Default value: "IBMCDB"
################################################################################
<xsl:choose>
	<xsl:when test="db/DBName">
#recovered:
-W CASInstall.DBName="<xsl:value-of select="db/DBName"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.DBName="IBMCDB"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Database Software Location
#   Location of the database application software that is used by the agent
#   registry.
#
#   DB2:
#     Windows: This is the DB2 install directory, e.g. "C:\Program Files\IBM\SQLLIB"
#     UNIX:    This is the home directory of the DB2 instance user plus the
#              "sqllib" directory appended. For example:
#
#   Oracle:
#     Solaris:  /opt/app/oracle
#
#   Cloudscape:
#     Not applicable; if data is supplied, AM ignores it since AM uses the
#     WebSphere Install location for Cloudscape.
#
#   Default Windows value: "C:\Program Files\IBM\SQLLIB"
#   Default AIX value:     "/data/db2users/db2inst1/sqllib"
#   Default Linux value:   "/home/db2inst1/sqllib"
#   Default Solaris value: "/export/home/db2inst1/sqllib"
#
################################################################################
<xsl:choose>
	<xsl:when test="db/DBLocation">
#recovered:
-W CASInstall.DBLocation="<xsl:value-of select="db/DBLocation"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.DBLocation="changeMe"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Database Runtime User ID
#   Represents a database user ID which will be used to configure the agent
#   manager's runtime access to the agent registry database.  This ID must
#   have the necessary authority to query, add, and update the database.
#
#   This value must be provided for DB2 and Oracle; for Cloudscape it is
#   ignored.
#
#   Default value: "db2admin"
################################################################################
-W CASInstall.DBRuntimeUserID=""

################################################################################
# Database Runtime Password
#   This is the password which corresponds to the DatabaseAdminUserID.
#
#   This value must be provided for DB2 and Oracle; for Cloudscape it is
#   ignored.
#
#   Default value: "db2admin"
################################################################################
-W CASInstall.DBRuntimePassword=""

################################################################################
# Database Provide Admin Credentials
#   This key allows the installer to dictate that two sets of database
#   credentials should be used during the agent manager installation: one to
#   create the database (the "Admin" credentials, and one to configure the
#   JDBC connection used by the agent manager when it runs (the "Runtime"
#   credentials).
#
#   If this key is set to "true", then the DBAdminUserID and DBAdminPassword
#   must be specified.
#
#   If this key is set to "false", the installer will use the DBRuntimeUserID
#   and DBRuntimePassword to configure the runtime access to the database, and
#   to create and configure the database tables (if necessary).
#
#   Valid values:   "true", "false"
#   Default value:  "false"
################################################################################
### -W CASInstall.DBProvideAdminCredentials="false"

################################################################################
# Database Admin User Name
#   Represents a database user ID which will be used to create the agent
#   registry database.  This ID must have the necessary authority to create
#   databases, update schema, and create tables.
#
#   This value must be specified if DBProvideAdminCredentials is set to "true".
#
#   Default value: "db2admin"
################################################################################
### -W CASInstall.DBAdminUserID="changeMe"

################################################################################
# Database Admin Password
#   This is the password which corresponds to the DatabaseAdminUserID.
#
#   This value must be specified if DBProvideAdminCredentials is set to "true".
#
#   Default value: "db2admin"
################################################################################
### -W CASInstall.DBAdminPassword="changeMe"

################################################################################
# Database Hostname
#   This value is used, in conjunction with the DBPort, to connect the agent
#   manager to a remote database using a JDBC Type 4 driver.
#
#   For "local" or "alias" database connections, this value is ignored.
#
#   This field can be either a TCP/IP address, a "shortname" or a fully
#   qualified hostname.  If a shortname is used, the host must either reside
#   in the same domain as the agent manager, or be in a domain contained in
#   the DNS suffix search order of the agent manager's host.
#
#   Default value: "localhost"
################################################################################
<xsl:choose>
	<xsl:when test="db/DBHostName">
#recovered:
-W CASInstall.DBHostname="<xsl:value-of select="db/DBHostName"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.DBHostname="localhost"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Database Port:
#   This value is used, in conjunction with the DBHostname, to connect the agent
#   manager to a remote database using a JDBC Type 4 driver.
#
#   For "local" or "alias" database connections, this value is ignored.
#
#   Normal database server application default values:
#   DB2:        50000
#   Oracle:     1521
#
#   Default value: 50000
################################################################################
<xsl:choose>
	<xsl:when test="db/DBPort">
#recovered:
-W CASInstall.DBPort="<xsl:value-of select="db/DBPort"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.DBPort="50000"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Agent Manager Hostname
#   This is the host name that is used by the Agent to contact Agent Manager.
#
#   If this option is commented out, the Agent Manager machine's hostname will
#   be autodetected. If you specify a value for this option, it must be a valid
#   DNS hostname or IP address.
#
#   This field can be either a TCP/IP address, a "shortname" or a fully
#   qualified hostname.  If a shortname is used, any agents or resource
#   managers attempting to use the agent manager must either reside in the
#   same domain as the agent manager, or contain the agent manager's domain
#   in their DNS suffix search order.
#
#   Default: "localhost"
################################################################################
<xsl:choose>
	<xsl:when test="general/agentManagerHostName">
#recovered:
-W CASInstall.AgentManagerHostname="<xsl:value-of select="general/agentManagerHostName"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.AgentManagerHostname=9.158.134.64
	</xsl:otherwise>
</xsl:choose>
################################################################################
# Agent Manager Application Server Name
#   The name of the WebSphere Application Server under which the Agent
#   Manager application will be installed.  If the server does not exist,
#   it will be created.  If it exists, the Agent Manager application will
#   be installed into the existing server.
#
#   This allows Agent Manager to share the WebSphere Application Server with
#   other applications.
#
#   Default value: AgentManager
################################################################################
<xsl:choose>
	<xsl:when test="container/serverName">
#recovered:
-W CASInstall.WASAppServerName="<xsl:value-of select="container/serverName"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.WASAppServerName=AgentManager
	</xsl:otherwise>
</xsl:choose>
################################################################################
# Agent Manager Registration Port
#   The port to which the Agent Manager will bind on startup to listen for
#   Agent registration requests.
#
#   Default value: "9511"
################################################################################
<xsl:choose>
	<xsl:when test="general/registrationPort">
#recovered:
-W CASInstall.RegistrationPort="<xsl:value-of select="general/registrationPort"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.RegistrationPort="9511"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Agent Manager Secure Port
#   The port to which the Agent Manager will bind on startup to listen for
#   secure communication requests.
#
#   Default value: "9512"
################################################################################
<xsl:choose>
	<xsl:when test="general/securePort">
#recovered:
-W CASInstall.SecurePort="<xsl:value-of select="general/securePort"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.SecurePort="9512"
	</xsl:otherwise>
</xsl:choose>
################################################################################
# Agent Manager Public Port
#   This port is used by both Agent Manager and the Agent Recovery Service
#   application. The Agent Recovery Service uses this port as a backup for port 80.
#
#   The port to which the Agent Manager will bind on startup to listen for
#   unsecure communication requests.
#
#   Default value: "9513"
################################################################################
<xsl:choose>
	<xsl:when test="general/publicPort">
#recovered:
-W CASInstall.PublicPort="<xsl:value-of select="general/publicPort"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.PublicPort="9513"
	</xsl:otherwise>
</xsl:choose>
################################################################################
# Agent Recovery Service Disable Port 80 Usage
#   This switch can be used to prevent the Agent Recovery Service from binding
#   to port 80.
#
#   "true":  The agent recovery service will NOT be configured to listen on
#            port 80. The agent recovery service will listen only on the
#            "PublicPort" value specified above.
#   "false": The agent recovery service will be configured to listen on
#            port 80 as well as on the "PublicPort" value
#            specified above.
#
#   Note:
#     Applications that run as a user without root authority will
#     experience "permission denied" problems in WebSphere Application
#     Server when the agent recovery service attempts to bind to port 80.
#     If you must install as a "non-root user" that does, then set this
#     key to "true".
#
#   Valid values:  "true", "false"
#   Default value: "false"
################################################################################
<xsl:choose>
	<xsl:when test="general/port80Disable">
#recovered:
-W CASInstall.DisablePort80="<xsl:value-of select="general/port80Disable"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.DisablePort80="false"
	</xsl:otherwise>
</xsl:choose>
################################################################################
# Agent Manager Start After Install
#   "true":  Agent Manager will automatically start after its install completes.
#   "false": Agent Manager will not be started after its install completes.
#
#   Valid values:  "true", "false"
#   Default value: "true"
################################################################################
<xsl:choose>
	<xsl:when test="general/startAfterInstall">
#recovered:
-W CASInstall.StartAfterInstall="<xsl:value-of select="general/startAfterInstall"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.StartAfterInstall="true"
	</xsl:otherwise>
</xsl:choose>
################################################################################
# Agent Manager Start After Reboot
#   "true":  Agent Manager will be configured to start automatically anytime
#            its host system rebooted.
#   "false": Agent Manager will not be configured to start automatically
#            anytime its host system is rebooted.
#
#   Valid values:  "true", "false"
#   Default value: "true"
################################################################################
<xsl:choose>
	<xsl:when test="general/startAfterReboot">
#recovered:
-W CASInstall.StartAfterReboot="<xsl:value-of select="general/startAfterReboot"/>"
	</xsl:when>
	<xsl:otherwise>
-W CASInstall.StartAfterReboot="true"
	</xsl:otherwise>
</xsl:choose>

################################################################################
# Agent Manager Password
#   This password is used (along with the Agent Registration Password) by the
#   agent manager to create the Certificate Authority Certificate and to
#   self-register with the Certificate Authority. It continues to be used
#   (whenever AM starts) to unlock the AM trust keystore (agentmanagertrust.jks)
#   and AM keystore (agentmanagerkeys.jks) files.
#
#   See the file header for a list of unsupported characters.
#
#   Note:
#     This option is surfaced only via the response file -- it is not
#     displayed during a GUI install.
#
#   Should be set manually during migration
################################################################################
 -W CASInstall.AgentManagerPassword=""

################################################################################
# Agent Manager Context Root
#   This is the Agent Manager specific directory (context root) that Agent Manager
#   will use under the installed WebSphere Application Server.
#
#   Note:
#     This option is surfaced only via the response file -- it is not
#     displayed during a GUI install.
#
# Default value: "/AgentMgr"
################################################################################
<xsl:choose>
	<xsl:when test="general/agentManagerContextRoot">
#recovered:
-W CASInstall.AgentManagerContextRoot="<xsl:value-of select="general/agentManagerContextRoot"/>"
	</xsl:when>
	<xsl:otherwise>
### -W CASInstall.AgentManagerContextRoot="/AgentMgr"
	</xsl:otherwise>
</xsl:choose>
################################################################################
# Relocation Image Location
#   Location of the AM image created by relocation tool. This option has impact 
#   only when W CASInstall.InstallType="relocate"
#
#   Default value: if not set current dir is assumed.
################################################################################
-W CASInstall.RelocationImageLocation="<xsl:value-of select="$destinationPath"/>" 

################################################################################
# WebSphere Application Server User ID
#   Represents a WebSphere Application Server secutity user ID which will be 
#   used to start, stop and check status of the server. This ID must
#   be the same as configured in WebSphere Application Server.
#
#   This value must be provided when WebSphere Application Server security 
#   is enabled.
#
################################################################################
### -W CASInstall.WASUserID=""


################################################################################
# WebSphere Application Server Password
#   This is the password which corresponds to the WASUserID.
#
#  This value must be provided when WebSphere Application Server security 
#  is enabled.
#
################################################################################
### -W CASInstall.WASPassword=""

</xsl:template>

<xsl:template match="@*|text()"/>
</xsl:stylesheet>



